@@ -1,8 +1,9 @@
 package App::gist;
 BEGIN {
-  $App::gist::VERSION = '0.01';
+  $App::gist::VERSION = '0.02';
 }
 
+use Getopt::Long;
 use File::Basename;
 use WWW::GitHub::Gist;
 
@@ -15,7 +16,7 @@ App::gist - GitHub Gist creator
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -45,11 +46,18 @@ sub new {
 
 	chomp $login; chomp $token;
 
+	my $update;
+
+	GetOptions(
+		"update=i" => \$update
+	);
+
 	my $opts = {
-		'file'  => $file,
-		'ext'   => $ext,
-		'login' => $login,
-		'token' => $token
+		'file'    => $file,
+		'ext'     => $ext,
+		'login'   => $login,
+		'token'   => $token,
+		'gist'    => $update
 	};
 
 	return bless $opts, $class;
@@ -64,7 +72,7 @@ Just run the app.
 sub run {
 	my $self = shift;
 
-	my ($login, $token, $ext);
+	my ($login, $token, $ext, $gist);
 
 	if (!$self -> {'login'}) {
 		print STDERR "Enter username: ";
@@ -96,15 +104,27 @@ sub run {
 		$ext = $self -> {'ext'};
 	}
 
-	my $gist = WWW::GitHub::Gist -> new(
-		user	=> $login,
-		token	=> $token
-	);
+	if ($self -> {'gist'}) {
+		$gist = WWW::GitHub::Gist -> new(
+			id	=> $self -> {'gist'},
+			user	=> $login,
+			token	=> $token
+		);
 
-	$gist -> add_file($basename, $data, $ext);
-	my $repo = $gist -> create -> {'repo'};
+		$gist -> add_file($basename, $data, $ext);
+		$gist -> update;
 
-	return $repo;
+		return $self -> {'gist'}
+	} else {
+		$gist = WWW::GitHub::Gist -> new(
+			user	=> $login,
+			token	=> $token
+		);
+
+		$gist -> add_file($basename, $data, $ext);
+
+		return $gist -> create -> {'repo'};
+	}
 }
 
 =head1 AUTHOR
